pub enum Capability {
FsRead {
root: PathRoot,
},
FsWrite {
root: PathRoot,
},
Network {
host: NetworkHost,
},
CrossComponentRead {
target: ComponentId,
},
}Expand description
One kind paired with its only valid scope type.
Variants
FsRead
Filesystem read authority rooted at root.
FsWrite
Filesystem write authority rooted at root.
Network
Network authority for exactly host.
Fields

host: NetworkHostExact host; no glob or pattern syntax is recognized.
CrossComponentRead
Read authority for exactly one foreign component.
Fields

target: ComponentIdComponent whose ephemeral read-only view may be resolved.
Implementations
Sourceimpl Capability
impl Capability
Sourcepub const fn kind(&self) -> CapabilityKind
pub const fn kind(&self) -> CapabilityKind
Returns the closed kind represented by this scoped capability.
Sourcepub fn scope(&self) -> CapabilityScope
pub fn scope(&self) -> CapabilityScope
Returns a typed copy of this capability’s scope.