pub enum CheckVerdict {
Allowed,
Denied(CapabilityDenied),
}Expand description
Fresh result of checking one consuming act.
Variants
Allowed
An active grant covered the act at check time.
Denied(CapabilityDenied)
No active grant covered the act at check time.