pub enum ComponentIdParseError {
Width {
actual: usize,
},
InvalidHex {
index: usize,
},
}Expand description
Why a textual component identity could not be constructed.
Variants
Width
The display form was not the required 64 ASCII bytes.
InvalidHex
A byte at the named display position was not hexadecimal.